@@ -10,7 +10,7 @@ from typing import AnyStr, Set, Collection, Any
 from socks import socksocket, SOCKS4, SOCKS5, HTTP
 from yarl import URL
 
-from PPK import GeoIP, Tools
+from PPK import Tools
 from PPK.Exceptions import ProxyInvalidHost, ProxyInvalidPort, ProxyParseError
 from PPK.Tools import Patterns
 
@@ -58,7 +58,6 @@ class Proxy(object):
         self.host = host
         self.type = proxy_type
         self.port = port
-        self.country = GeoIP.get(host)
         if self.country:
             self.country = self.country["registered_country"]["iso_code"]
         self.user = user or None
